import { Component, OnChanges, SimpleChanges, Input } from '@angular/core';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { ILogs } from 'src/app/models/logs.model';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'app-logs-data',
  templateUrl: './logs-data.component.html',
  styleUrls: ['./logs-data.component.scss'],
})
export class LogsDataComponent implements OnChanges {
  @Input() childUuid: string = '';
  @Input() childSessionId: string = '';
  @Input() childSlug: string;
  displayedStep: string = 'none';
  logTypes: any = [
    {
      name : 'erreurs',
      selected : false,
    },
    {
      name : 'infos',
      selected : true,
    },
  ];
  uuid: string;
  sessionId: string;
  slug: string;
  data: any;
  stepData: ILogs;
  allStepsData: any;
  allErrorLogs: any;
  allLogs: any;
  nbSessionId: number;
  nbUuid: number;
  nbSlug: number;
  tempStep: string = '';

  sessionIdList: [string];
  constructor(
    private dataLogsService: DataLogsService,
    private route: ActivatedRoute,
  ) { }

  ngOnChanges(changes: SimpleChanges): void {
    this.data = [];
    this.slug = this.childSlug;
    this.allStepsData = [];
    this.allErrorLogs = [];
    this.getLogsSteps();
  }

  getLogsSteps() {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getAllStepsDuration(
        this.childUuid,
        this.childSessionId,
      ).subscribe((results) => {
        console.log('getAllStepsDuration results', results);
        this.allStepsData = results;
      },
      );
    }
  }
  getLogsSelector(step) {
    this.tempStep = step;
    this.allErrorLogs = [];
    this.allLogs = [];
    this.displayedStep = step;
    if (this.logTypes[0].selected === true) {
      this.getErrorStepsLogs(step);
    }
    if (this.logTypes[1].selected === true) {
      this.getSimpleStepsLogs(step);
    }
  }
  getErrorStepsLogs(step) {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getLogsStepsLogs(
        step,
        this.childSessionId,
        this.childUuid,
        'ERROR',
      ).subscribe((results) => {
        // console.log('results', results);
        this.allErrorLogs = results;
      },
      );
    }
  }
  getSimpleStepsLogs(step) {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getLogsStepsLogs(
        step,
        this.childSessionId,
        this.childUuid,
        'INFO',
      ).subscribe((results) => {
        // console.log('results', results);
        this.allLogs = results;
      },
      );
    }
  }
}
