import { Component, OnChanges, SimpleChanges, Input } from '@angular/core';
import { Chart } from 'chart.js';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { ILogs } from 'src/app/models/logs.model';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'app-logs-graph',
  templateUrl: './logs-graph.component.html',
  styleUrls: ['./logs-graph.component.scss'],
})
export class LogsGraphComponent implements OnChanges {
  @Input() childUuid: string;
  @Input() childSessionId: string;
  @Input() childSlug: string;

  public myChart: Chart;
  graphData: any;
  uuid: string;
  sessionId: string;
  dataset: any;
  xValues: any;
  yValues: any;

  constructor(
    private dataLogsService: DataLogsService,
  ) { }
  ngOnChanges(changes: SimpleChanges): void {
    this.graphData = [0.2, 0.3];
    this.xValues = [];
    this.yValues = [];
    this.dataset = [];
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      this.getData();
    }
  }

  plotGraph() {

    this.myChart = new Chart(document.getElementById('graphCanvas'), {
      type: 'scatter',
      data: {
        datasets: this.dataset,
      },
      options: {
        title: {
          display: true,
          text: 'Logs-chart: progress-report.',
        },
        legend: {
          display: true,
          position: 'right',
        },
        elements: {
          line: {
            tension: 0, // disables bezier curves
          },
        },
        responsive: true,
        scales: {
          xAxes: [{
            type: 'time',
            display: true,
            scaleLabel: {
              display: true,
              labelString: 'Time',
            },
            ticks: {
              major: {
                fontStyle: 'bold',
                fontColor: '#FF0000',
              },
            },
          }],
          yAxes: [{
            display: true,
            scaleLabel: {
              display: true,
              labelString: 'progress-ratio',
            },
          }],
        },
      },

    });
  }

  getXYValuesFromData() {
    const color = ['red', 'yellow', 'blue', 'black', 'pink', 'green', 'orange'];
    let c = 0;
    this.dataset = [];
    for (const data of this.graphData) {
      const arrayOfXY = [];
      for (const i in data.values) {
        const XY = {
          x: data.timestamps[i].$date,

          y: data.values[i],
        };
        arrayOfXY.push(XY);
      }
      const tempObj = {
        label: data._id.step,
        showLine: true,
        backgroundColor: color[c],
        borderColor: color[c],
        fill: false,
        data: arrayOfXY,
        lineTension: 0.3,
      };
      this.dataset.push(tempObj);
      c += 1;
    }
  }
  replotGraph() {
    this.getData();
    this.myChart.update();
  }
  getData() {
    this.dataLogsService.getData(this.childUuid, this.childSessionId).subscribe((results) => {
      console.log(results);
      this.graphData = results;
      this.getXYValuesFromData();
      this.plotGraph();
    },
    );
  }
}
