import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { filter, switchMap } from 'rxjs/operators';
import { Format } from 'src/app/models/format.model';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { IPageHeaderInfo } from 'src/app/models/page.model';

@Component({
  selector: 'app-logs-pre-report',
  templateUrl: './logs-pre-report.component.html',
  styleUrls: ['./logs-pre-report.component.scss'],
})
export class LogsPreReportComponent implements OnInit {
  pageHeaderInfo: IPageHeaderInfo = {
    title: 'Data-Logs Pre-report',
  };
  previousUrl: string = '/datalogs';
  responseArray: any = [];
  form: FormGroup;
  title: string;
  type: string ;
  id: string;
  serviceName:string;
  nbObjects: number = 0;
  isSession:boolean = false;
  allSlugsInfoList:any = [];
  allSessionsInfoList: any = [];

  oneTempSlugsInfo:any = [];

  constructor(
    private _dataLogsService: DataLogsService,
    public _route: ActivatedRoute,
    private _router: Router,
    private _fb: FormBuilder,
  ) {
  }

  ngOnInit() {
    this.title = this._route.snapshot.data.title;
    this.previousUrl = '/datalogs';
    this.id = this._route.snapshot.paramMap.get('id');
    this.type = this._route.snapshot.paramMap.get('type');
    if (this.type === 'session') {
      this.isSession = true;
    }

    this._route.paramMap.pipe(
      filter((paramMap: ParamMap) => (paramMap.get('id') !== null)),
      filter((paramMap: ParamMap) => (paramMap.get('type') !== null)),
      switchMap((paramMap: ParamMap) => this._dataLogsService.getComplementaryFromSlugOrSession(
        paramMap.get('type'),
        paramMap.get('id'))))
      .subscribe((response) => {

        this.responseArray = response[0];
        if (this.type === 'session') {
          this.nbObjects = response[0].slug_list.length;
          console.log('response[0]', response[0]);
          this.completeSlugsInfos(response[0].slug_list);
        } else {
          this.nbObjects = response[0].session_id_list.length;
          console.log('response[0]', response[0]);
          this.completeSessionsInfos(response[0].session_id_list);
        }
        // console.log('responseArray: ', this.responseArray);
        // console.log('nbObjects: ', this.nbObjects);

      });
  }
  completeSlugsInfos(slugList) {
    this.allSlugsInfoList = [];
    for (let i = 0; i < slugList.length; i += 1) {
      console.log('slugList[i]', slugList[i]);
      this.getAllInfoForOneSlug(slugList[i]);
    }
  }
  getAllInfoForOneSlug(slug) {
    this._dataLogsService.getAllInfoForOneSlug(slug).subscribe((result) => {
      console.log('result[0]', result[0]);
      for (let j = 0; j < result[0].data.length; j += 1) {
        result[0].data[j].completionDate.$date = new Date(result[0].data[j].completionDate.$date);
      }
      this.allSlugsInfoList.push(result[0]) ;
    },
    );

  }

  completeSessionsInfos(sessionList) {
    this.allSessionsInfoList = [];
    for (let i = 0; i < sessionList.length; i += 1) {
      console.log('sessionList[i]', sessionList[i]);
      this.getAllInfoForOneSession(sessionList[i]);
    }
  }
  getAllInfoForOneSession(sessionId) {
    this._dataLogsService.getAllInfoForOneSession(sessionId).subscribe((result) => {
      console.log('result[0]', result[0]);
      for (let j = 0; j < result[0].data.length; j += 1) {
        result[0].data[j].completionDate.$date = new Date(result[0].data[j].completionDate.$date);
      }
      this.allSessionsInfoList.push(result[0]) ;
    },
    );

  }

}
